#####install and load required packages
if("ggplot2" %in% installed.packages()) {} else {
  install.packages("ggplot2")
}

library(ggplot2)


###load data
films <- read.csv("films.csv", head=T, quote="'")

###find years & box office

##add column for years
current_length <- length(films)
films[current_length+1] <- NA; colnames(films)[current_length+1] <- "Year"

##add column for box office
current_length <- length(films)
films[current_length+1] <- NA; colnames(films)[current_length+1] <- "Box_Office"

##add column for Ebert Stars
current_length <- length(films)
films[current_length+1] <- NA; colnames(films)[current_length+1] <- "Ebert_Stars"

##get years and box office
for(i in 1:length(films$Film)) {
  ##get data from boxofficemojo.com:
  temp <- readLines(con=paste("http://www.boxofficemojo.com/search/?q=", gsub(" ", "%20", films$Film[i]), sep=""))
  
  
  if(length(grep("<tr bgcolor=#FFFF99>", temp))>0) {
    temp <- temp[grep("<tr bgcolor=#FFFF99>", temp):length(temp)]
  } else if(length(grep("1 Movie Matches", temp))>0) {
    temp <- temp[grep("1 Movie Matches", temp):length(temp)]
  } else {
    temp <- NA
  }
  
  if(is.na(temp)) {
    films$Year[i] = films$Box_Office[i] = NA
  } else {
    films$Box_Office[i] = gsub("[^0-9]", "", unlist(strsplit(grep("<td align=\"right\"><font size=\"2\"  face=\"verdana\">",temp,value=T)[1], "\\$"))[2], perl=T)
    
    ###in case of multiple releases, the release year is not given in the search overview
    ###therefore we have to extract it from the movie page
    
    ##get link
    link2 <- unlist(strsplit(grep("movies/\\?id\\=", temp, value=T)[1], "a href=\"|\\.htm"))[2]
    
    ##use link
    temp002 <- readLines(con=paste("http://www.boxofficemojo.com", link2, ".htm", sep=""))
    
    ##get year
    if(length(grep("release\\=theatrical&date\\=", temp002))>0) {
      films$Year[i] <- unlist(strsplit(unlist(strsplit(grep("Release Date\\: ", temp002, value=T), "release\\=theatrical&date\\="))[2], "-"))[1]
      
    } else {
      films$Year[i] <- gsub(" ", "", unlist(strsplit(unlist(strsplit(grep("Release Date\\:", temp002, value=T), "Release Date\\:"))[2], ",|</nobr"))[2])
    }
    
    
    
  }
}


####get Ebert Stars
for(i in 1:length(films$Film)) {
  ##get the review page
  tryCatch({  
    review_page <- readLines(con=tolower(paste("http://www.rogerebert.com/reviews/", paste(gsub(" ", "-", films$Film[i]), films$Year[i], sep="-"), sep="")))
    
    
    ##cut it down to the relevant <span> element:
    if(length(grep("reviewRating", review_page))>0) {
      review_page <- review_page[grep("reviewRating", review_page):length(review_page)]
      review_page <- review_page[1:grep("</span>", review_page)[1]]
      
      ##get rating
      rating <- 0
      rating <- rating + length(grep("icon-star-full", unlist(strsplit(review_page[2], "<|>")))) + 
        0.5*length(grep("icon-star-half", unlist(strsplit(review_page[2], "<|>"))))
      films$Ebert_Stars[i] <- rating
    } else {
      films$Ebert_Stars[i] <- NA
    }
    
    
  }, error = function(e){})
}


###plot data
myPlot <- ggplot(films, aes(films$Ebert_Stars, as.numeric(films$Box_Office)/1000000), na.rm=T)
myPlot + geom_point() + geom_smooth(method="lm", col="red", fill="blue", alpha=0.1) + labs(x="Ebert's rating", y="Box office (in mio. $)") +
  ggtitle("Ebert Stars and Box Office Results") +
  theme(plot.title=element_text(vjust=2, face="bold"))

##save plot
ggsave(filename="Ebert_Ratings4.png", width=6, height=6)


###fit a linear model to the data
summary(lm(films$Ebert_Stars~as.numeric(films$Box_Office), na.action=na.omit))




###################################################
########EXCURSUS: ERROR-PRONE FUNCTION#############

##define function
errorpronefunction <- function(x) {
  if(x %in% c(5,7,9)) {
    stop("This is a nasty error")
  }
  return(x+pi)
}

##execute function - this won't work very well due to the inbuilt error:
for(i in 1:10) {
  print(errorpronefunction(i))
}


##execute function with tryCatch:
for(i in 1:10) {
  tryCatch({
    print(errorpronefunction(i))
  },
  error=function(e) {cat(conditionMessage(e), "\n")})
}

